/*
 * Ball.java
 *
 * Created on September 14, 2005, 10:13 PM
 *
 * BallWorld for ENGR2510, fall 2005 at Olin, part of the CS101 project
 * (c)2005 Olin College
 */

package ballworld;

/**
 * Describes the properties and user interactions of a Ball in BallWorld.
 * These are all methods that will be called on your Ball by the World
 * or because of some user interaction.
 *
 * @author Mike Wessler
 */
public interface Ball {
    
    /**
     * Gets the x coordinate of the center of the ball.
     * @return the x coordinate of the center of the ball
     */
    public double getX();
    
    /**
     * Gets the y coordinate of the center of the ball.
     * @return the y coordinate of the center of the ball
     */
    public double getY();
    
    /**
     * Gets the radius of the ball.
     * @return the radius of the ball
     */
    public double getRadius();
    
    /**
     * Tells this ball about the world to which it has been added.
     * This method will be called immediately after the ball has been added
     * to the world, and before any other methods are called by the world on
     * this ball.
     * @param world the World to which this ball has been added
     */
    public void setWorld(World world);
    
    /**
     * Tells this ball that the user has dragged or released the mouse at
     * a given location.
     * @param xLoc the x location of the drag or click
     * @param yLoc the y location of the drag or click
     */
    public void userDragged(double xLoc, double yLoc);
    
    /**
     * Tells this ball that the user has typed a printable character while
     * this ball was selected.  If the character is not printable (like the
     * arrow or control keys), this method may not be called.
     * @param ch the character that was typed.
     */
    public void userTyped(char ch);
}
